@@ -1,8 +1,8 @@
 """Test the pypdf.filters module."""
 import os
-import shutil
 import string
 import subprocess
+import sys
 import zlib
 from io import BytesIO
 from itertools import product as cartesian_product
@@ -38,7 +38,7 @@ from pypdf.generic import (
     StreamObject,
 )
 
-from . import PILContext, get_data_from_url
+from . import PILContext, get_data_from_url, get_image_data
 from .test_encryption import HAS_AES
 from .test_images import image_similarity
 
@@ -307,7 +307,7 @@ for page in reader.pages:
     except KeyError:
         env["PYTHONPATH"] = "."
     result = subprocess.run(  # noqa: S603  # We have the control here.
-        [shutil.which("python"), source_file],
+        [sys.executable, source_file],
         capture_output=True,
         env=env,
     )
@@ -365,7 +365,7 @@ def test_png_transparency_reverse():
     data = reader.pages[0].images[0]
     img = Image.open(BytesIO(data.data))
     assert ".jp2" in data.name
-    assert list(img.getdata()) == list(refimg.getdata())
+    assert get_image_data(img) == get_image_data(refimg)
 
 
 @pytest.mark.enable_socket
@@ -376,7 +376,7 @@ def test_iss1787():
     data = reader.pages[0].images[0]
     img = Image.open(BytesIO(data.data))
     assert ".png" in data.name
-    assert list(img.getdata()) == list(refimg.getdata())
+    assert get_image_data(img) == get_image_data(refimg)
     obj = data.indirect_reference.get_object()
     obj["/DecodeParms"][NameObject("/Columns")] = NumberObject(1000)
     obj.decoded_self = None
@@ -392,7 +392,7 @@ def test_tiff_predictor():
     data = reader.pages[0].images[0]
     img = Image.open(BytesIO(data.data))
     assert ".png" in data.name
-    assert list(img.getdata()) == list(refimg.getdata())
+    assert get_image_data(img) == get_image_data(refimg)
 
 
 @pytest.mark.enable_socket
@@ -665,8 +665,8 @@ def test_ccitt_fax_decode__black_is_1():
 
     actual_image = reader.pages[0].images[0].image
     expected_image_inverted = other_reader.pages[0].images[0].image
-    expected_pixels = list(ImageOps.invert(expected_image_inverted).getdata())
-    actual_pixels = list(actual_image.getdata())
+    expected_pixels = get_image_data(ImageOps.invert(expected_image_inverted))
+    actual_pixels = get_image_data(actual_image)
     assert expected_pixels == actual_pixels
 
     # AttributeError: 'NullObject' object has no attribute 'get'
@@ -893,3 +893,12 @@ def test_decompress():
                 LimitReachedError, match=r"^Limit reached while decompressing\. 12 bytes remaining\."
             ):
         decompress(compressed)
+
+
+def test_decompress__logging_on_invalid_data(caplog):
+    """We do not like suddenly getting empty outputs for non-empty inputs without a warning."""
+    codec = FlateDecode()
+    encoded = codec.encode(b"My test string")
+    assert len(encoded) > 5
+    assert codec.decode(encoded[5:]) == b""
+    assert caplog.messages == ["Error -3 while decompressing data: incorrect header check"]
