@@ -11,7 +11,7 @@ from pypdf.constants import FilterTypes, ImageAttributes, StreamAttributes
 from pypdf.errors import EmptyImageDataError, PdfReadError
 from pypdf.generic import ArrayObject, DecodedStreamObject, NameObject, NumberObject, StreamObject, TextStringObject
 
-from . import get_data_from_url
+from . import get_data_from_url, get_image_data
 
 TESTS_ROOT = Path(__file__).parent.resolve()
 PROJECT_ROOT = TESTS_ROOT.parent
@@ -39,7 +39,7 @@ def test_get_imagemode_recursion_depth():
 def test_handle_flate__image_mode_1(caplog):
     data = b"\x00\xe0\x00"
     lookup = DecodedStreamObject()
-    expected_data = [
+    expected_data = (
         (66, 66, 66),
         (66, 66, 66),
         (66, 66, 66),
@@ -49,7 +49,7 @@ def test_handle_flate__image_mode_1(caplog):
         (66, 66, 66),
         (66, 66, 66),
         (66, 66, 66),
-    ]
+    )
 
     # No trailing data.
     lookup.set_data(b"\x42\x42\x42\x00\x13\x37")
@@ -63,7 +63,7 @@ def test_handle_flate__image_mode_1(caplog):
         colors=2,
         obj_as_text="dummy",
     )
-    assert expected_data == list(result[0].getdata())
+    assert expected_data == get_image_data(result[0])
     assert not caplog.text
 
     # Trailing whitespace.
@@ -78,7 +78,7 @@ def test_handle_flate__image_mode_1(caplog):
         colors=2,
         obj_as_text="dummy",
     )
-    assert expected_data == list(result[0].getdata())
+    assert expected_data == get_image_data(result[0])
     assert not caplog.text
 
     # Trailing non-whitespace character.
@@ -98,7 +98,7 @@ def test_handle_flate__image_mode_1(caplog):
         colors=2,
         obj_as_text="dummy",
     )
-    assert expected_data == list(result[0].getdata())
+    assert expected_data == get_image_data(result[0])
     assert "Too many lookup values: Expected 6, got 7." in caplog.text
 
     # Not enough lookup data.
@@ -106,7 +106,7 @@ def test_handle_flate__image_mode_1(caplog):
     # here, but received a custom padding of `0`.
     lookup.set_data(b"\x42\x42\x42\x00\x13")
     caplog.clear()
-    expected_short_data = [entry if entry[0] == 66 else (0, 19, 0) for entry in expected_data]
+    expected_short_data = tuple([entry if entry[0] == 66 else (0, 19, 0) for entry in expected_data])
     result = _handle_flate(
         size=(3, 3),
         data=data,
@@ -122,7 +122,7 @@ def test_handle_flate__image_mode_1(caplog):
         colors=2,
         obj_as_text="dummy",
     )
-    assert expected_short_data == list(result[0].getdata())
+    assert expected_short_data == get_image_data(result[0])
     assert "Not enough lookup values: Expected 6, got 5." in caplog.text
 
 
